@@ -53,6 +53,11 @@ const StatusBadgeMini = ({
       badgeStyle.push('bg-green-500 border-green-400 ring-green-400 text-green-100');
       indicatorIcon = /*#__PURE__*/react_jsx_runtime__WEBPACK_IMPORTED_MODULE_4__.jsx(_heroicons_react_24_solid__WEBPACK_IMPORTED_MODULE_2__.MinusSmallIcon, {});
       break;
+
+    case _server_constants_media__WEBPACK_IMPORTED_MODULE_3__/* .MediaStatus.DELETED */ .Jp.DELETED:
+      badgeStyle.push('bg-red-500 border-red-400 ring-red-400 text-red-100');
+      indicatorIcon = /*#__PURE__*/react_jsx_runtime__WEBPACK_IMPORTED_MODULE_4__.jsx(_heroicons_react_24_solid__WEBPACK_IMPORTED_MODULE_2__.TrashIcon, {});
+      break;
   }
 
   if (inProgress) {
@@ -448,7 +453,7 @@ const TitleCard = ({
                 children: /*#__PURE__*/react_jsx_runtime__WEBPACK_IMPORTED_MODULE_16__.jsx("div", {
                   className: "flex h-full w-full items-end",
                   children: /*#__PURE__*/(0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_16__.jsxs)("div", {
-                    className: `px-2 text-white ${!showRequestButton || currentStatus && currentStatus !== _server_constants_media__WEBPACK_IMPORTED_MODULE_12__/* .MediaStatus.UNKNOWN */ .Jp.UNKNOWN ? 'pb-2' : 'pb-11'}`,
+                    className: `px-2 text-white ${!showRequestButton || currentStatus && currentStatus !== _server_constants_media__WEBPACK_IMPORTED_MODULE_12__/* .MediaStatus.UNKNOWN */ .Jp.UNKNOWN && currentStatus !== _server_constants_media__WEBPACK_IMPORTED_MODULE_12__/* .MediaStatus.DELETED */ .Jp.DELETED ? 'pb-2' : 'pb-11'}`,
                     children: [year && /*#__PURE__*/react_jsx_runtime__WEBPACK_IMPORTED_MODULE_16__.jsx("div", {
                       className: "text-sm font-medium",
                       children: year
@@ -466,7 +471,7 @@ const TitleCard = ({
                     }), /*#__PURE__*/react_jsx_runtime__WEBPACK_IMPORTED_MODULE_16__.jsx("div", {
                       className: "whitespace-normal text-xs",
                       style: {
-                        WebkitLineClamp: !showRequestButton || currentStatus && currentStatus !== _server_constants_media__WEBPACK_IMPORTED_MODULE_12__/* .MediaStatus.UNKNOWN */ .Jp.UNKNOWN ? 5 : 3,
+                        WebkitLineClamp: !showRequestButton || currentStatus && currentStatus !== _server_constants_media__WEBPACK_IMPORTED_MODULE_12__/* .MediaStatus.UNKNOWN */ .Jp.UNKNOWN && currentStatus !== _server_constants_media__WEBPACK_IMPORTED_MODULE_12__/* .MediaStatus.DELETED */ .Jp.DELETED ? 5 : 3,
                         display: '-webkit-box',
                         overflow: 'hidden',
                         WebkitBoxOrient: 'vertical',
@@ -479,7 +484,7 @@ const TitleCard = ({
               })
             }), /*#__PURE__*/react_jsx_runtime__WEBPACK_IMPORTED_MODULE_16__.jsx("div", {
               className: "absolute bottom-0 left-0 right-0 flex justify-between px-2 py-2",
-              children: showRequestButton && (!currentStatus || currentStatus === _server_constants_media__WEBPACK_IMPORTED_MODULE_12__/* .MediaStatus.UNKNOWN */ .Jp.UNKNOWN) && /*#__PURE__*/(0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_16__.jsxs)(_app_components_Common_Button__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, {
+              children: showRequestButton && (!currentStatus || currentStatus === _server_constants_media__WEBPACK_IMPORTED_MODULE_12__/* .MediaStatus.UNKNOWN */ .Jp.UNKNOWN || currentStatus === _server_constants_media__WEBPACK_IMPORTED_MODULE_12__/* .MediaStatus.DELETED */ .Jp.DELETED) && /*#__PURE__*/(0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_16__.jsxs)(_app_components_Common_Button__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, {
                 buttonType: "primary",
                 buttonSize: "sm",
                 onClick: e => {
