@@ -1,7 +1,5 @@
 import { MediaRequestStatus } from '@server/constants/media';
-import { getRepository } from '@server/datasource';
 import {
-  AfterRemove,
   Column,
   CreateDateColumn,
   Entity,
@@ -36,18 +34,6 @@ class SeasonRequest {
   constructor(init?: Partial<SeasonRequest>) {
     Object.assign(this, init);
   }
-
-  @AfterRemove()
-  public async handleRemoveParent(): Promise<void> {
-    const mediaRequestRepository = getRepository(MediaRequest);
-    const requestToBeDeleted = await mediaRequestRepository.findOneOrFail({
-      where: { id: this.request.id },
-    });
-
-    if (requestToBeDeleted.seasons.length === 0) {
-      await mediaRequestRepository.delete({ id: this.request.id });
-    }
-  }
 }
 
 export default SeasonRequest;
