@@ -281,7 +281,9 @@ class BaseScanner<T> {
               ? MediaStatus.AVAILABLE
               : season.episodes > 0
               ? MediaStatus.PARTIALLY_AVAILABLE
-              : !season.is4kOverride && season.processing
+              : !season.is4kOverride &&
+                season.processing &&
+                existingSeason.status !== MediaStatus.DELETED
               ? MediaStatus.PROCESSING
               : existingSeason.status;
 
@@ -294,7 +296,9 @@ class BaseScanner<T> {
               ? MediaStatus.AVAILABLE
               : this.enable4kShow && season.episodes4k > 0
               ? MediaStatus.PARTIALLY_AVAILABLE
-              : season.is4kOverride && season.processing
+              : season.is4kOverride &&
+                season.processing &&
+                existingSeason.status4k !== MediaStatus.DELETED
               ? MediaStatus.PROCESSING
               : existingSeason.status4k;
         } else {
@@ -324,19 +328,25 @@ class BaseScanner<T> {
         }
       }
 
+      // We want to skip specials when checking if a show is available
       const isAllStandardSeasons =
         seasons.length &&
-        seasons.every(
-          (season) =>
-            season.episodes === season.totalEpisodes && season.episodes > 0
-        );
+        seasons
+          .filter((season) => season.seasonNumber !== 0)
+          .every(
+            (season) =>
+              season.episodes === season.totalEpisodes && season.episodes > 0
+          );
 
       const isAll4kSeasons =
         seasons.length &&
-        seasons.every(
-          (season) =>
-            season.episodes4k === season.totalEpisodes && season.episodes4k > 0
-        );
+        seasons
+          .filter((season) => season.seasonNumber !== 0)
+          .every(
+            (season) =>
+              season.episodes4k === season.totalEpisodes &&
+              season.episodes4k > 0
+          );
 
       if (media) {
         media.seasons = [...media.seasons, ...newSeasons];
@@ -398,16 +408,23 @@ class BaseScanner<T> {
         }
 
         // If the show is already available, and there are no new seasons, dont adjust
-        // the status
+        // the status. Skip specials when performing availability check
         const shouldStayAvailable =
           media.status === MediaStatus.AVAILABLE &&
-          newSeasons.filter((season) => season.status !== MediaStatus.UNKNOWN)
-            .length === 0;
+          newSeasons.filter(
+            (season) =>
+              season.status !== MediaStatus.UNKNOWN &&
+              season.status !== MediaStatus.DELETED &&
+              season.seasonNumber !== 0
+          ).length === 0;
         const shouldStayAvailable4k =
           media.status4k === MediaStatus.AVAILABLE &&
-          newSeasons.filter((season) => season.status4k !== MediaStatus.UNKNOWN)
-            .length === 0;
-
+          newSeasons.filter(
+            (season) =>
+              season.status4k !== MediaStatus.UNKNOWN &&
+              season.status4k !== MediaStatus.DELETED &&
+              season.seasonNumber !== 0
+          ).length === 0;
         media.status =
           isAllStandardSeasons || shouldStayAvailable
             ? MediaStatus.AVAILABLE
@@ -417,11 +434,13 @@ class BaseScanner<T> {
                   season.status === MediaStatus.AVAILABLE
               )
             ? MediaStatus.PARTIALLY_AVAILABLE
-            : !seasons.length ||
+            : (!seasons.length && media.status !== MediaStatus.DELETED) ||
               media.seasons.some(
                 (season) => season.status === MediaStatus.PROCESSING
               )
             ? MediaStatus.PROCESSING
+            : media.status === MediaStatus.DELETED
+            ? MediaStatus.DELETED
             : MediaStatus.UNKNOWN;
         media.status4k =
           (isAll4kSeasons || shouldStayAvailable4k) && this.enable4kShow
@@ -433,11 +452,13 @@ class BaseScanner<T> {
                   season.status4k === MediaStatus.AVAILABLE
               )
             ? MediaStatus.PARTIALLY_AVAILABLE
-            : !seasons.length ||
+            : (!seasons.length && media.status4k !== MediaStatus.DELETED) ||
               media.seasons.some(
                 (season) => season.status4k === MediaStatus.PROCESSING
               )
             ? MediaStatus.PROCESSING
+            : media.status4k === MediaStatus.DELETED
+            ? MediaStatus.DELETED
             : MediaStatus.UNKNOWN;
         await mediaRepository.save(media);
         this.log(`Updating existing title: ${title}`);
