@@ -201,8 +201,8 @@ router.get<{ userId: number }>(
   }
 );
 
-router.get<{ userId: number; key: string }>(
-  '/:userId/pushSubscription/:key',
+router.get<{ userId: number; endpoint: string }>(
+  '/:userId/pushSubscription/:endpoint',
   async (req, res, next) => {
     try {
       const userPushSubRepository = getRepository(UserPushSubscription);
@@ -213,7 +213,7 @@ router.get<{ userId: number; key: string }>(
         },
         where: {
           user: { id: req.params.userId },
-          p256dh: req.params.key,
+          endpoint: req.params.endpoint,
         },
       });
 
@@ -224,8 +224,8 @@ router.get<{ userId: number; key: string }>(
   }
 );
 
-router.delete<{ userId: number; key: string }>(
-  '/:userId/pushSubscription/:key',
+router.delete<{ userId: number; endpoint: string }>(
+  '/:userId/pushSubscription/:endpoint',
   async (req, res, next) => {
     try {
       const userPushSubRepository = getRepository(UserPushSubscription);
@@ -236,7 +236,7 @@ router.delete<{ userId: number; key: string }>(
         },
         where: {
           user: { id: req.params.userId },
-          p256dh: req.params.key,
+          endpoint: req.params.endpoint,
         },
       });
 
@@ -245,7 +245,7 @@ router.delete<{ userId: number; key: string }>(
     } catch (e) {
       logger.error('Something went wrong deleting the user push subcription', {
         label: 'API',
-        key: req.params.key,
+        endpoint: req.params.endpoint,
         errorMessage: e.message,
       });
       return next({
