@@ -16,7 +16,7 @@ import {
   TrashIcon,
   XMarkIcon,
 } from '@heroicons/react/24/solid';
-import { MediaRequestStatus } from '@server/constants/media';
+import { MediaRequestStatus, MediaStatus } from '@server/constants/media';
 import type { MediaRequest } from '@server/entity/MediaRequest';
 import type { MovieDetails } from '@server/models/Movie';
 import type { TvDetails } from '@server/models/Tv';
@@ -417,6 +417,15 @@ const RequestCard = ({ request, onTitleData }: RequestCardProps) => {
               >
                 {intl.formatMessage(globalMessages.failed)}
               </Badge>
+            ) : requestData.status === MediaRequestStatus.PENDING &&
+              requestData.media[requestData.is4k ? 'status4k' : 'status'] ===
+                MediaStatus.DELETED ? (
+              <Badge
+                badgeType="warning"
+                href={`/${requestData.type}/${requestData.media.tmdbId}?manage=1`}
+              >
+                {intl.formatMessage(globalMessages.pending)}
+              </Badge>
             ) : (
               <StatusBadge
                 status={
